Authors and Developers
======================

The following persons contributed to the development of the |pyam| package:

- Matthew Gidden `@gidden <https://github.com/gidden>`_
- Daniel Huppmann `@danielhuppmann <https://github.com/danielhuppmann>`_
- Zebedee Nicholls `@znicholls <https://github.com/znicholls>`_
- Nikolay Kushin `@zikolach <https://github.com/zikolach>`_
- Robin Lamboll `@Rlamboll <https://github.com/Rlamboll>`_
- Oliver Fricko `@OFR-IIASA <https://github.com/OFR-IIASA>`_
- Jonas Hörsch `@coroa <https://github.com/coroa>`_
- Paul Natsuo Kishimoto `@khaeru <https://github.com/khaeru>`_
- Thorsten Burandt `@tburandt <https://github.com/tburandt>`_
- Ross Ursino `@rossursino <https://github.com/rossursino>`_
- Maik Budzinski `@mabudz <https://github.com/mabudz>`_
- Jarmo Kikstra `@jkikstra <https://github.com/jkikstra>`_
- Michael Pimmer `@fonfon <https://github.com/fonfon>`_
- Patrick Jürgens `@pjuergens <https://github.com/pjuergens>`_
- Florian Maczek `@macflo8 <https://github.com/macflo8>`_
- Laura Wienpahl `@LauWien <https://github.com/LauWien>`_
- Philip Hackstock `@phackstock <https://github.com/phackstock>`_
- Pietro Monticone `@pitmonticone <https://github.com/pitmonticone>`_
- Edward Byers `@byersiiasa <https://github.com/byersiiasa>`_
- Fridolin Glatter `@glatterf42 <https://github.com/glatterf42>`_
- Linh Ho `@linhho <https://github.com/LinhHo>`

| The core maintenance of the |pyam| package is done by
  the *Scenario Services & Scientific Software* research theme
  at the IIASA Energy, Climate, and Environment program.
| Visit https://software.ece.iiasa.ac.at for more information.
